Moneta
======

TODO
----

  * gérer les groupes externes (via LDAP)
  * commande pour nettoyer (supprimer les paquets sans état)

    * miroirs :
        * Jetbrains
        * brew
        * Perl
        * LaTeX
        * Ruby
        * PHP
        * JS
